summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--gtk/proto_hier_stats_dlg.h14
-rw-r--r--gtk/range_utils.h32
-rw-r--r--gtk/recent.h27
-rw-r--r--gtk/rtp_analysis.h7
-rw-r--r--gtk/rtp_stream.h7
-rw-r--r--gtk/rtp_stream_dlg.h24
-rw-r--r--gtk/service_response_time_table.h6
-rw-r--r--gtk/summary_dlg.h14
-rw-r--r--gtk/supported_protos_dlg.h16
-rw-r--r--gtk/tap_dfilter_dlg.h14
-rw-r--r--gtk/tap_menu.h42
-rw-r--r--gtk/text_page.h11
12 files changed, 169 insertions, 45 deletions
diff --git a/gtk/proto_hier_stats_dlg.h b/gtk/proto_hier_stats_dlg.h
index c0a520a230..9bde408feb 100644
--- a/gtk/proto_hier_stats_dlg.h
+++ b/gtk/proto_hier_stats_dlg.h
@@ -1,6 +1,6 @@
/* proto_hier_stats_dlg.h
*
- * $Id: proto_hier_stats_dlg.h,v 1.2 2002/09/05 18:47:47 jmayer Exp $
+ * $Id: proto_hier_stats_dlg.h,v 1.3 2004/06/02 22:13:04 ulfl Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@zing.org>
@@ -25,7 +25,15 @@
#ifndef __PROTO_HIER_STATS_DLG_H__
#define __PROTO_HIER_STATS_DLG_H__
-void
-proto_hier_stats_cb(GtkWidget *w, gpointer d);
+/** @file
+ * "Protocol Hierarchy" statistics window.
+ */
+
+/** Show protocol hierarchy statistics.
+ *
+ * @param widget parent widget (unused)
+ * @param data unused
+ */
+extern void proto_hier_stats_cb(GtkWidget *widget, gpointer data);
#endif
diff --git a/gtk/range_utils.h b/gtk/range_utils.h
index 75a1e2c6da..823217a470 100644
--- a/gtk/range_utils.h
+++ b/gtk/range_utils.h
@@ -1,7 +1,7 @@
/* range_utils.h
* Declarations of utilities to with range_utils.c (packet range dialog)
*
- * $Id: range_utils.h,v 1.1 2004/04/22 21:29:34 ulfl Exp $
+ * $Id: range_utils.h,v 1.2 2004/06/02 22:13:04 ulfl Exp $
*
* Ulf Lamping <ulf.lamping@web.de>
*
@@ -27,20 +27,42 @@
#ifndef __RANGE_UTILS_H__
#define __RANGE_UTILS_H__
-/* create a new range "widget" */
+/** @file
+ * Packet range widget used for example in the "Save" and "Print" dialogs.
+ */
+
+/** Create a new range widget.
+ *
+ * @param range the range to set
+#if GTK_MAJOR_VERSION < 2
+ * @param accel_group accelerator group (GTK1 only)
+#endif
+ * @return the new range widget
+ */
extern GtkWidget *range_new(packet_range_t *range
#if GTK_MAJOR_VERSION < 2
, GtkAccelGroup *accel_group
#endif
);
-/* update all "dynamic" things */
+/* Update all "dynamic" range things.
+ *
+ * @param data range widget
+ */
extern void range_update_dynamics(gpointer data);
-/* set the "Process only marked packets" toggle button as appropriate */
+/** Set the "Process only marked packets" toggle button as appropriate.
+ *
+ * @param data range widget
+ * @param marked_valid TRUE, if marked packets available
+ */
extern void range_set_marked_sensitive(gpointer data, gboolean marked_valid);
-/* set the "displayed" button as appropriate */
+/** Set the "displayed" button as appropriate.
+ *
+ * @param data range widget
+ * @param displayed_valid TRUE, if displayed packets available
+ */
extern void range_set_displayed_sensitive(gpointer data, gboolean displayed_valid);
#endif
diff --git a/gtk/recent.h b/gtk/recent.h
index 4c1ca8cc39..34bcde560a 100644
--- a/gtk/recent.h
+++ b/gtk/recent.h
@@ -2,7 +2,7 @@
* Definitions for recent "preference" handling routines
* Copyright 2004, Ulf Lamping <ulf.lamping@web.de>
*
- * $Id: recent.h,v 1.9 2004/05/30 11:54:37 ulfl Exp $
+ * $Id: recent.h,v 1.10 2004/06/02 22:13:04 ulfl Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -28,10 +28,17 @@
#include <glib.h>
+/** @file
+ * Recent user interface settings.
+ */
+/** ???. */
#define RECENT_KEY_CAPTURE_FILE "recent.capture_file"
+
+/** ???. */
#define RECENT_KEY_DISPLAY_FILTER "recent.display_filter"
+/** Recent settings. */
typedef struct recent_settings_tag {
gboolean main_toolbar_show;
gboolean filter_toolbar_show;
@@ -54,13 +61,29 @@ typedef struct recent_settings_tag {
gint gui_geometry_status_pane; /* this is valid in GTK2 only */
} recent_settings_t;
+/** Global recent settings. */
extern recent_settings_t recent;
-
+/** Write recent settings file.
+ *
+ * @param rf_path_return path to recent file if function failed
+ * @return 0 if succeeded, errno if failed
+ */
extern int write_recent(char **rf_path_return);
+/** Read recent settings file.
+ *
+ * @param rf_path_return path to recent file if function failed
+ * @param rf_errno_return if failed
+ */
extern void read_recent(char **rf_path_return, int *rf_errno_return);
+/** Write the geometry values of a single window to the recent file.
+ *
+ * @param key unused
+ * @param value the geometry values
+ * @param rf recent file handle (FILE)
+ */
extern void write_recent_geom(gpointer key, gpointer value, gpointer rf);
#endif /* recent.h */
diff --git a/gtk/rtp_analysis.h b/gtk/rtp_analysis.h
index ae5afc571f..b18fa0bebd 100644
--- a/gtk/rtp_analysis.h
+++ b/gtk/rtp_analysis.h
@@ -1,7 +1,7 @@
/* rtp_analysis.h
* RTP analysis addition for ethereal
*
- * $Id: rtp_analysis.h,v 1.1 2003/09/24 07:48:11 guy Exp $
+ * $Id: rtp_analysis.h,v 1.2 2004/06/02 22:13:04 ulfl Exp $
*
* Copyright 2003, Alcatel Business Systems
* By Lars Ruoff <lars.ruoff@gmx.net>
@@ -34,6 +34,11 @@
#include <glib.h>
+/** @file
+ * ???
+ * @todo what's this?
+ */
+
void rtp_analysis(
guint32 ip_src_fwd, /* network-order IPv4 address */
guint16 port_src_fwd,
diff --git a/gtk/rtp_stream.h b/gtk/rtp_stream.h
index bdd8df665a..ffd9f38e69 100644
--- a/gtk/rtp_stream.h
+++ b/gtk/rtp_stream.h
@@ -1,7 +1,7 @@
/* rtp_stream.h
* RTP streams summary addition for ethereal
*
- * $Id: rtp_stream.h,v 1.5 2004/01/26 19:16:30 obiot Exp $
+ * $Id: rtp_stream.h,v 1.6 2004/06/02 22:13:04 ulfl Exp $
*
* Copyright 2003, Alcatel Business Systems
* By Lars Ruoff <lars.ruoff@gmx.net>
@@ -31,6 +31,11 @@
#include <glib.h>
#include <stdio.h>
+/** @file
+ * ???
+ * @todo what's this?
+ */
+
/****************************************************************************/
/* type for storing rtp frame information */
typedef struct st_rtp_sample_header {
diff --git a/gtk/rtp_stream_dlg.h b/gtk/rtp_stream_dlg.h
index 69f7dd9cee..a3efd09fb1 100644
--- a/gtk/rtp_stream_dlg.h
+++ b/gtk/rtp_stream_dlg.h
@@ -1,7 +1,7 @@
/* rtp_stream_dlg.h
* RTP streams summary addition for ethereal
*
- * $Id: rtp_stream_dlg.h,v 1.1 2003/09/24 07:48:11 guy Exp $
+ * $Id: rtp_stream_dlg.h,v 1.2 2004/06/02 22:13:04 ulfl Exp $
*
* Copyright 2003, Alcatel Business Systems
* By Lars Ruoff <lars.ruoff@gmx.net>
@@ -30,16 +30,22 @@
#include <gtk/gtk.h>
-/*
-* Create or reactivate the rtp streams dialog box.
-* list: pointer to list of rtp_stream_info_t*
-*/
+/** @file
+ * "RTP Stream Analysis" dialog box.
+ */
+
+/**
+ * Create or reactivate the rtp streams dialog box.
+ *
+ * @param list pointer to list of rtp_stream_info_t*
+ */
void rtpstream_dlg_show(GList *list);
-/*
-* Update the contents of the dialog box clist with that of list.
-* list: pointer to list of rtp_stream_info_t*
-*/
+/**
+ * Update the contents of the dialog box clist with that of list.
+ *
+ * @param list pointer to list of rtp_stream_info_t*
+ */
void rtpstream_dlg_update(GList *list);
#endif /*RTP_STREAM_DLG_H_INCLUDED*/
diff --git a/gtk/service_response_time_table.h b/gtk/service_response_time_table.h
index d98e2414be..74e3b47942 100644
--- a/gtk/service_response_time_table.h
+++ b/gtk/service_response_time_table.h
@@ -3,7 +3,7 @@
* Helper routines common to all service response time statistics
* tap.
*
- * $Id: service_response_time_table.h,v 1.2 2003/09/05 10:26:44 sahlberg Exp $
+ * $Id: service_response_time_table.h,v 1.3 2004/06/02 22:13:04 ulfl Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -27,6 +27,10 @@
#include <gtk/gtk.h>
#include "epan/nstime.h"
+/** @file
+ * Helper routines common to all service response time statistics tap.
+ * @todo complete this?
+ */
typedef struct _srt_procedure_t {
char *entries[6];
diff --git a/gtk/summary_dlg.h b/gtk/summary_dlg.h
index 35c6662e48..840d4d0109 100644
--- a/gtk/summary_dlg.h
+++ b/gtk/summary_dlg.h
@@ -1,7 +1,7 @@
/* summary_dlg.h
* Routines for capture file summary window
*
- * $Id: summary_dlg.h,v 1.2 2000/04/01 09:16:49 guy Exp $
+ * $Id: summary_dlg.h,v 1.3 2004/06/02 22:13:04 ulfl Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@zing.org>
@@ -26,6 +26,16 @@
#ifndef __SUMMARY_DLG_H__
#define __SUMMARY_DLG_H__
-void summary_open_cb(GtkWidget *w, gpointer d);
+/** @file
+ * "Summary" dialog box.
+ */
+
+/**
+ * Create the summary dialog box.
+ *
+ * @param widget parent widget (unused)
+ * @param data unused
+ */
+void summary_open_cb(GtkWidget *widget, gpointer data);
#endif /* __SUMMARY_DLG_H__ */
diff --git a/gtk/supported_protos_dlg.h b/gtk/supported_protos_dlg.h
index 0d81257c57..360c39fed8 100644
--- a/gtk/supported_protos_dlg.h
+++ b/gtk/supported_protos_dlg.h
@@ -2,7 +2,7 @@
*
* Laurent Deniel <laurent.deniel@free.fr>
*
- * $Id: supported_protos_dlg.h,v 1.2 2004/02/20 22:37:50 guy Exp $
+ * $Id: supported_protos_dlg.h,v 1.3 2004/06/02 22:13:04 ulfl Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@zing.org>
@@ -27,9 +27,19 @@
#ifndef __SUPPORTED_DLG_H__
#define __SUPPORTED_DLG_H__
-void supported_cb(GtkWidget *, gpointer);
+/** @file
+ * "Supported Protocols" dialog box.
+ */
+
+/**
+ * Create the supported protos dialog box.
+ *
+ * @param widget parent widget (unused)
+ * @param data unused
+ */
+void supported_cb(GtkWidget *widget, gpointer data);
-/* Redraw all the text widgets, to use a new font. */
+/** Redraw all the supported protos text widgets, to use a new font. */
void supported_redraw(void);
#endif
diff --git a/gtk/tap_dfilter_dlg.h b/gtk/tap_dfilter_dlg.h
index 142f9d5917..b11645a0ca 100644
--- a/gtk/tap_dfilter_dlg.h
+++ b/gtk/tap_dfilter_dlg.h
@@ -2,7 +2,7 @@
* Header file for display filter dialog used by GTK gui taps
* Copyright 2003 Lars Roland
*
- * $Id: tap_dfilter_dlg.h,v 1.2 2003/12/19 23:41:55 guy Exp $
+ * $Id: tap_dfilter_dlg.h,v 1.3 2004/06/02 22:13:04 ulfl Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -23,4 +23,14 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
-void gtk_tap_dfilter_dlg_cb(GtkWidget *w, gpointer data);
+/** @file
+ * Display filter dialog box used by GTK gui taps.
+ */
+
+/**
+ * Create the filter dialog box.
+ *
+ * @param widget parent widget (unused)
+ * @param data the dfilter tap dialog
+ */
+void gtk_tap_dfilter_dlg_cb(GtkWidget *widget, gpointer data);
diff --git a/gtk/text_page.h b/gtk/text_page.h
index 2cbdf04db4..fa795f01b2 100644
--- a/gtk/text_page.h
+++ b/gtk/text_page.h
@@ -1,7 +1,7 @@
/* text_page.h
* Declarations of routine to construct a simple text page from a file.
*
- * $Id: text_page.h,v 1.1 2004/05/22 04:25:57 guy Exp $
+ * $Id: text_page.h,v 1.2 2004/06/02 22:13:04 ulfl Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -25,6 +25,15 @@
#ifndef __TEXT_PAGE_H__
#define __TEXT_PAGE_H__
+/** @file
+ * Construct a simple text page widget from a file.
+ */
+
+/** Construct a simple text page widget from a file (UTF8 encoded).
+ *
+ * @param absolute_path the path to the text file
+ * @return the new widget
+ */
extern GtkWidget * text_page_new(const char *absolute_path);
#endif /* __TEXT_PAGE_H__ */
diff --git a/gtk/tap_menu.h b/gtk/tap_menu.h
index 0ed78e8e0f..bfc710c92a 100644
--- a/gtk/tap_menu.h
+++ b/gtk/tap_menu.h
@@ -1,7 +1,7 @@
/* tap_menu.h
* Menu definitions for use by taps
*
- * $Id: tap_menu.h,v 1.4 2004/02/23 20:28:31 ulfl Exp $
+ * $Id: tap_menu.h,v 1.5 2004/06/02 22:13:04 ulfl Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -29,43 +29,55 @@
extern "C" {
#endif /* __cplusplus */
-/*
+/** @file
+ * Add a new menu item for a tap.
+ */
+
+/** The menu group this tap should be registered at. */
+typedef struct {
+ REGISTER_TAP_GROUP_NONE,
+ REGISTER_TAP_GROUP_GENERIC,
+ REGISTER_TAP_GROUP_CONVERSATION_LIST,
+ REGISTER_TAP_GROUP_ENDPOINT_LIST,
+ REGISTER_TAP_GROUP_RESPONSE_TIME
+} REGISTER_TAP_GROUP_E;
+
+/**
* Add a new menu item for a tap.
* This must be called after we've created the main menu, so it can't
* be called from the routine that registers taps - we have to introduce
* another per-tap registration routine.
*
* "callback" gets called when the menu item is selected; it should do
* the work of creating the tap window.
*
- * "selected_packet_enabled" gets called by "set_menus_for_selected_packet()";
+ * @param selected_packet_enabled gets called by set_menus_for_selected_packet();
* it's passed a pointer to the "frame_data" structure for the current frame,
* if any, and to the "epan_dissect_t" structure for that frame, if any, and
* should return TRUE if the tap will work now (which might depend on whether
* a frame is selected and, if one is, on the frame) and FALSE if not.
*
- * "selected_tree_row_enabled" gets called by
- * "set_menus_for_selected_tree_row()"; it's passed a pointer to the
+ * @param selected_tree_row_enabled gets called by
+ * set_menus_for_selected_tree_row(); it's passed a pointer to the
* "field_info" structure for the currently selected field, if any,
* and should return TRUE if the tap will work now (which might depend on
* whether a tree row is selected and, if one is, on the tree row) and
* FALSE if not.
- */
+ *
+ * @param callback_data data for callback function
+ */
extern void register_tap_menu_item(
char *name,
- gint group,
+ REGISTER_TAP_GROUP_E group,
GtkItemFactoryCallback callback,
gboolean (*selected_packet_enabled)(frame_data *, epan_dissect_t *),
gboolean (*selected_tree_row_enabled)(field_info *),
gpointer callback_data);
-/* XXX: would it better to use an enum here? */
-#define REGISTER_TAP_GROUP_GENERIC 0
-#define REGISTER_TAP_GROUP_CONVERSATION_LIST 1
-#define REGISTER_TAP_GROUP_ENDPOINT_LIST 2
-#define REGISTER_TAP_GROUP_RESPONSE_TIME 3
-#define REGISTER_TAP_GROUP_NONE 10
-
#ifdef __cplusplus
}
#endif /* __cplusplus */
@@ -29,43 +29,55 @@
* another per-tap registration routine.
*
- * "callback" gets called when the menu item is selected; it should do
+ * @param name the menu label
+ *
+ * @param group the menu group, this tap should be registered to
+ *
+ * @param callback gets called when the menu item is selected; it should do
* the work of creating the tap window.
*